api.authentication.v1.user.test_helpers.user_apikey package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.user.test_helpers.user_apikey package

## Submodules

## api.authentication.v1.user.test_helpers.user_apikey.disable_method_for_user module

`api.authentication.v1.user.test_helpers.user_apikey.disable_method_for_user.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/disable/w+, respond with HTTP 403

`api.authentication.v1.user.test_helpers.user_apikey.disable_method_for_user.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/disable/w+, respond with HTTP 404

`api.authentication.v1.user.test_helpers.user_apikey.disable_method_for_user.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/disable/w+, respond with HTTP 200

`api.authentication.v1.user.test_helpers.user_apikey.disable_method_for_user.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/disable/w+, respond with HTTP 401

## api.authentication.v1.user.test_helpers.user_apikey.enable_method_for_user module

`api.authentication.v1.user.test_helpers.user_apikey.enable_method_for_user.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/enable/w+, respond with HTTP 403

`api.authentication.v1.user.test_helpers.user_apikey.enable_method_for_user.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/enable/w+, respond with HTTP 404

`api.authentication.v1.user.test_helpers.user_apikey.enable_method_for_user.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/enable/w+, respond with HTTP 200

`api.authentication.v1.user.test_helpers.user_apikey.enable_method_for_user.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/enable/w+, respond with HTTP 401

## api.authentication.v1.user.test_helpers.user_apikey.get_user_methods module

`api.authentication.v1.user.test_helpers.user_apikey.get_user_methods.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/methods, respond with HTTP 403

`api.authentication.v1.user.test_helpers.user_apikey.get_user_methods.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/methods, respond with HTTP 404

`api.authentication.v1.user.test_helpers.user_apikey.get_user_methods.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/methods, respond with HTTP 200

`api.authentication.v1.user.test_helpers.user_apikey.get_user_methods.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/methods, respond with HTTP 401

## api.authentication.v1.user.test_helpers.user_apikey.initiate module

`api.authentication.v1.user.test_helpers.user_apikey.initiate.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/totp, respond with HTTP 403

`api.authentication.v1.user.test_helpers.user_apikey.initiate.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/totp, respond with HTTP 404

`api.authentication.v1.user.test_helpers.user_apikey.initiate.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/totp, respond with HTTP 200

`api.authentication.v1.user.test_helpers.user_apikey.initiate.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/totp, respond with HTTP 401

## api.authentication.v1.user.test_helpers.user_apikey.list module

`api.authentication.v1.user.test_helpers.user_apikey.list.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/apikey, respond with HTTP 403

`api.authentication.v1.user.test_helpers.user_apikey.list.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/apikey, respond with HTTP 404

`api.authentication.v1.user.test_helpers.user_apikey.list.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/apikey, respond with HTTP 200

`api.authentication.v1.user.test_helpers.user_apikey.list.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/apikey, respond with HTTP 401

## api.authentication.v1.user.test_helpers.user_apikey.renew module

`api.authentication.v1.user.test_helpers.user_apikey.renew.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/apikey/w+, respond with HTTP 403

`api.authentication.v1.user.test_helpers.user_apikey.renew.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/apikey/w+, respond with HTTP 404

`api.authentication.v1.user.test_helpers.user_apikey.renew.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/apikey/w+, respond with HTTP 200

`api.authentication.v1.user.test_helpers.user_apikey.renew.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/apikey/w+, respond with HTTP 401

## api.authentication.v1.user.test_helpers.user_apikey.retrieve_s_m_s_token module

`api.authentication.v1.user.test_helpers.user_apikey.retrieve_s_m_s_token.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/sms/token/w+, respond with HTTP 403

`api.authentication.v1.user.test_helpers.user_apikey.retrieve_s_m_s_token.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/sms/token/w+, respond with HTTP 404

`api.authentication.v1.user.test_helpers.user_apikey.retrieve_s_m_s_token.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/sms/token/w+, respond with HTTP 200

`api.authentication.v1.user.test_helpers.user_apikey.retrieve_s_m_s_token.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/sms/token/w+, respond with HTTP 401

## api.authentication.v1.user.test_helpers.user_apikey.revoke module

`api.authentication.v1.user.test_helpers.user_apikey.revoke.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/totp, respond with HTTP 403

`api.authentication.v1.user.test_helpers.user_apikey.revoke.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/totp, respond with HTTP 404

`api.authentication.v1.user.test_helpers.user_apikey.revoke.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/totp, respond with HTTP 200

`api.authentication.v1.user.test_helpers.user_apikey.revoke.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/user/w+/totp, respond with HTTP 401

## Module contents